<?php

namespace Drupal\humanitix_api;

/**
 * The Humanitix data provider interface.
 */
interface DataProviderInterface {

  /**
   * Loads an individual item from the Eventbrite API.
   *
   * @param string $type
   *   The data type to load.
   * @param string $id
   *   The ID of the data to load.
   * @param array $query
   *   Custom query options.
   *
   * @return \Drupal\Core\TypedData\TypedDataInterface|null
   *   Returns typed data of the requested item or NULL if it doesn't exist.
   */
  public function get(string $type, string $id, array $query = []);

  /**
   * Loads many items from the Eventbrite API.
   *
   * @param string $type
   *   The data type to load.
   * @param array $query
   *   Additional query values which can limit the returned items.
   * @param int $offset
   *   A result from which to begin.
   * @param int $count
   *   The number of results to fetch. -1 for no limit.
   *
   * @return \Iterator
   *   An iterator which returns TypedDataInterfaces for the requested data.
   */
  public function getMultiple(string $type, array $query = [], int $offset = 0, int $count = -1);

}
